@@ -35,6 +35,8 @@
 #' If age_bars_colored_by specifies a variable (not NULL), you must provide
 #' two colors, low and high values for a gradient. Colors must be either R
 #' valid color names or valid hex codes.
+#' 
+#' @param age_bars_width (numeric; 1.5) Change line width for age bars
 #'
 #' @param node_labels (character; NULL) Plot text labels at nodes, specified
 #' by the name of the corresponding column in the tidytree object. If NULL,
@@ -136,6 +138,7 @@ plotFBDTree <- function(
                         tip_age_bars = TRUE,
                         age_bars_color = "blue",
                         age_bars_colored_by = NULL,
+                        age_bars_width = 1.5,
 
                         node_labels = NULL,
                         node_labels_color = "black",
@@ -174,6 +177,7 @@ plotFBDTree <- function(
                tip_age_bars = tip_age_bars,
                age_bars_color = age_bars_color,
                age_bars_colored_by = age_bars_colored_by,
+               age_bars_width = age_bars_width,
 
                node_labels = node_labels,
                node_labels_color = node_labels_color,
